********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Date: 		11/10/2023
*** Author: 	Nishant Yonzan
*** Purpose: 	Get the headcount, poverty gap, mean and median for 2019 
***				using anchored-SPL for poor and non-poor groups. Estimate the 
***				values for alpha.
********************************************************************************

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/Alpha.log", replace

********************************************************************************

*****************************************
*** MEAN, MEDIAN OF POOR AND NON-POOR ***
*****************************************

use "InputData/GlobalDist_1000bins_2019-2023_sep23", clear						// global dataset
keep if year==2019
keep country code  quantile pop welf

preserve																		// overall mean and median
gen median2019  = welf
gen mean2019 	= welf
collapse (mean) mean2019 (p50) median2019 [aw=pop], by(code)
tempfile overall
save 	`overall'
restore

merge m:1 code using `overall', nogen

gen socpovline2019 		= max(2.15, 1.15 + median2019/2)						// anchored socpovline in 2019
gen socpov 				= welf	 < socpovline2019								// indicator for poor under the SPL	

preserve																		// mean, median of poor and non-poor
gen median2019_group  = welf
gen mean2019_group 	= welf
collapse mean2019_group (p50) median2019_group [aw=pop], by(code socpov)
reshape wide mean2019_group median2019_group, i(code) j(socpov)
tempfile bygrp
save 	`bygrp'
restore

merge m:1 code using `bygrp', nogen

gen 	povgap = 1 - welf/socpovline2019										// poverty gap under the SPL
replace povgap = 0 if welf>socpovline2019

collapse socpov mean2019* median2019* socpovline2019 povgap (rawsum) pop [aw=pop], by(country code)

gen socpoor = socpov * pop														// number of societal poor
replace socpov = socpov * 100

keep 	country code socpovline2019 socpov socpoor povgap mean2019* median2019*
order 	country code socpovline2019 socpov socpoor povgap mean2019* median2019* 

********************************************************
*** COUNTRY-LEVEL ALPHA VALUES USING MEAN AND MEDIAN ***
********************************************************

scalar e111 = 1.11
scalar e150 = 1.5
scalar e200 = 2
scalar y_su = 1.075

gen ybar_p = mean2019_group1
gen ybar_n = mean2019_group0
gen ymed_p = median2019_group1
gen ymed_n = median2019_group0

gen alpha_mean_e111 = 1 / ( 1 - ( (ybar_p^(1-e111) - y_su^(1-e111)) / (ybar_n^(1-e111) - y_su^(1-e111)) ))
gen alpha_medi_e111 = 1 / ( 1 - ( (ymed_p^(1-e111) - y_su^(1-e111)) / (ymed_n^(1-e111) - y_su^(1-e111)) ))
gen alpha_mean_e150 = 1 / ( 1 - ( (ybar_p^(1-e150) - y_su^(1-e150)) / (ybar_n^(1-e150) - y_su^(1-e150)) ))
gen alpha_medi_e150 = 1 / ( 1 - ( (ymed_p^(1-e150) - y_su^(1-e150)) / (ymed_n^(1-e150) - y_su^(1-e150)) ))
gen alpha_mean_e200 = 1 / ( 1 - ( (ybar_p^(1-e200) - y_su^(1-e200)) / (ybar_n^(1-e200) - y_su^(1-e200)) ))
gen alpha_medi_e200 = 1 / ( 1 - ( (ymed_p^(1-e200) - y_su^(1-e200)) / (ymed_n^(1-e200) - y_su^(1-e200)) ))

drop ybar* ymed*

label var socpovline2019 "SPL in 2019"
label var socpov 		 "Societal poverty in 2019, %"
label var socpoor 		 "Societal poverty in 2019, millions"
label var povgap 		 "Poverty gap in 2019 using the SPL in 2019"
label var mean2019 		 "Mean welfare in 2019, 2017 PPP $/day"
label var median2019 	 "Median welfare in 2019, 2017 PPP $/day"
label var mean2019_group0 	"Mean welfare in 2019 of non-poor, 2017 PPP $/day"
label var mean2019_group1 	"Mean welfare in 2019 of poor, 2017 PPP $/day"
label var median2019_group0 "Median welfare in 2019 of non-poor, 2017 PPP $/day"
label var median2019_group1 "Median welfare in 2019 of poor, 2017 PPP $/day"

label var alpha_mean_e111 "Alpha using mean income with CRRA 1.11"
label var alpha_medi_e111 "Alpha using median income with CRRA 1.11"
label var alpha_mean_e150 "Alpha using mean income with CRRA 1.50"
label var alpha_medi_e150 "Alpha using median income with CRRA 1.50"
label var alpha_mean_e200 "Alpha using mean income with CRRA 2.00"
label var alpha_medi_e200 "Alpha using median income with CRRA 2.00"

sort code
export excel using "OutputData/Alpha.xlsx", first(varlabels) replace
save "OutputData/Alpha.dta", replace

********************************************************************************

log close
