********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Date: 		11/10/2023
*** Author: 	Nishant Yonzan
*** Purpose: 	Use human capital adjusted growth rates to project societal 
***				poverty to 2100 for LLL paper. Calculate total additional number 
***				of poor and discount it to 2020.
********************************************************************************

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/FPY.log", replace

********************************************************************************

************************
*** PRELIMINARY DATA ***
************************
					
use "InputData/CLASS_historical.dta", clear										// country groups in 2019
keep if year_fiscal==2019
ren economy country
keep country code region incgroup_historical
ren region region_wb
ren incgroup_historical incgroup2019
label var incgroup2019 "World Bank income classification, FY2019" 
tempfile class
save `class', replace
																				
import delimited "InputData/WEOOct2022all.xls", clear							//  GDPPC in 2019, WEO
keep if subjectdescriptor=="Gross domestic product per capita, constant prices" & units=="Purchasing power parity; 2017 international dollar"
local yr = 1980
foreach var of varlist v* {
	rename `var' gdppc`yr'
	local yr = `yr' + 1
}
keep iso gdppc2019 gdppc2020
reshape long gdppc, i(iso) j(year)
replace gdppc = "" if inlist(gdppc,"--","n/a")
destring gdppc, replace ignore("chars" [, ignoreopts]) 
bys iso: gen ggdppc = gdppc/gdppc[_n-1] - 1
ren iso code
reshape wide gdppc ggdppc, i(code) j(year)
keep code gdppc2019 ggdppc2020
label var gdppc2019  "WEO per capita GDP, 2017 PPP USD"
label var ggdppc2020 "WEO per capita GDP growth"
ren gdppc2019  gdppc2019_weo
ren ggdppc2020 ggdppc2020_weo
tempfile gdppc_weo
save 	`gdppc_weo', replace
																				
import delimited "InputData/WEOOct2022all.xls", clear							// population in 2019 from WEO 
keep if subjectdescriptor=="Population"
keep iso v*
foreach var of varlist v* {
	local lab: variable label `var'
	ren `var' pop`lab' 
	replace pop`lab' = "" if inlist(pop`lab',"--","n/a")
}
destring pop*, replace ignore("chars" [, ignoreopts]) 
gen gpop2020_weo = pop2020/pop2019 - 1
keep iso pop2019 gpop2020_weo
ren iso code
tempfile population_weo
save `population_weo', replace

import excel using "InputData/OUTPUT_default_nolinks_31March2023.xlsx", ///
	sheet(Baseline) first clear													// population to 2100 
local yr = 2020
foreach var of varlist C-CE {
	rename `var' gpop`yr'
	local yr = `yr' + 1
}
gen numcode = substr(A, -1,.)	
keep if numcode=="1"
keep A gpop*
ren A code
replace code = substr(code,1,3)
merge 1:1 code using `population_weo', nogen keep(3)
replace gpop2020 = gpop2020_weo if missing(gpop2020)							// POL and MOZ missing population growth for 2020
gen pop2020 = pop2019 * (1+gpop2020)
forval yr = 2021/2100 {
    local i = `yr' - 1
    gen pop`yr' = pop`i' * (1+gpop`yr')
}
drop gpop* 
tempfile pop2100
save 	`pop2100', replace

********************************************
*** PIP COUNTRIES BY INCOME/CONSUMPTION  ***
********************************************

*ssc install pip
// list of all countries
pip tables, table(country_list) clear $pipoptions
keep country_code country_name pcn_region_code region_code
tempfile countryname
save 	`countryname'


// get list of lineups and keep the latest lineup to use for nowcasts
pip, clear $pipoptions fillgaps
keep country_code welfare_type reporting_level year
merge m:1 country_code using `countryname', nogen
bys country_code (year): gen lastyear = year[_N]
keep if year==lastyear
drop year lastyear

drop if reporting_level!="national" & inlist(country_code,"CHN","IDN","IND") 	// keep only national obs for these countries


// gen inPIP variable
gen 	inPIP = "Yes" if !missing(reporting_level)
replace inPIP = "No"  if missing(inPIP) 

// Venezuela special case
replace welfare_type = . 	 if country_code == "VEN"
replace reporting_level = "" if country_code == "VEN"
replace inPIP = "No"  		 if country_code == "VEN"

ren country_name country
ren country_code code
ren pcn_region_code region_pip
ren region_code 	region_wb
ren reporting_level coverage

label var inPIP "Survey in PIP in last lineup year?"
order country code region_pip inPIP coverage welfare_type
drop region_wb

tempfile PIP_countries
save 	`PIP_countries', replace

*******************************
*** GROWTH DATA FROM ARTHUR ***
*******************************

import excel using "InputData/OUTPUT_default_nolinks_31March2023.xlsx", ///
	sheet(Baseline) first clear													// growth rates  
gen type = "Baseline"	
tempfile baseline
save 	`baseline'	

import excel using "InputData/OUTPUT_default_nolinks_31March2023.xlsx", ///
	sheet(Scenario) first clear
gen type = "Scenario"

append using `baseline'
	
local yr = 2020
foreach var of varlist C-CE {
	rename `var' ggdppc`yr'
	local yr = `yr' + 1
}

gen numcode = substr(A, -1,.)	
keep if numcode=="7"	
keep A type ggdppc*
ren A code
replace code = substr(code,1,3)

reshape long ggdppc, i(code type) j(year)

*******************************
*** MERGE WITH GROWTH DATA ***
*******************************

// 2020 actual growth rates for those with missing growth
merge m:1 code using `gdppc_weo', keep(1 3) nogen keepusing(ggdppc2020_weo)		
replace ggdppc = ggdppc2020_weo if missing(ggdppc)
drop ggdppc2020_weo

// growth pass-through rates for income and consumption specific surveys
preserve
use `PIP_countries', clear
keep code welfare_type
tempfile welftype
save `welftype', replace
restore 

merge m:1 code using `welftype', keep(1 3) nogen
replace ggdppc = ggdppc * 0.7 if inlist(welfare_type,1,.) 						// missing or consumption
replace ggdppc = ggdppc * 1.0 if welfare_type==2
drop welfare_type

reshape wide ggdppc, i(code type) j(year)
ren ggdppc* ggdppc*_
reshape wide ggdppc*_, i(code) j(type) string

tempfile hc_growth
save 	`hc_growth', replace

**********************************************************************
*** Projection to 2100, using distribution neutral 2020 projection ***
**********************************************************************

use "InputData/GlobalDist_1000bins_2019-2023_sep23", clear						// 2019 welfare vector from PIP
keep if year==2019 
keep code quantile welf
ren welf welf2019	

merge m:1 code using `hc_growth', nogen keep(2 3)

// projection to 2100
gen welf2020_Baseline = welf2019 * (1+ggdppc2020_Baseline)
gen welf2020_Scenario = welf2019 * (1+ggdppc2020_Scenario)
forval yr = 2021/2100 {
    local i = `yr' - 1
    gen welf`yr'_Baseline = welf`i'_Baseline * (1+ggdppc`yr'_Baseline)
	gen welf`yr'_Scenario = welf`i'_Scenario * (1+ggdppc`yr'_Scenario)
}
drop ggdppc`yr'*

bysort code: egen median2019 = median(welf2019) 								// anchored socpovline in 2019
gen 	socpovline2019 	= max(2.15, 1.15 + median2019/2)
drop welf2019

reshape long welf, i(code quantile) j(id) string
gen year = substr(id,1,4)
gen type = substr(id,6,.)
destring year, replace
drop id
replace type = "Baseline" if year==2019 										// remove this line if not using 2019

gen pov 				= welf < 2.15											// extreme poverty
gen socpov 				= welf < socpovline2019									// absolute poverty using anchored 2019 SPL

collapse pov socpov, by(code year type)
reshape wide pov socpov, i(code type) j(year)
order code type pov*
foreach v of varlist pov* socpov* {
    replace `v' = `v' * 100
}
format %5.1f pov* socpov*

merge m:1 code using `class', 			keep(1 3) nogen
merge m:1 code using `gdppc_weo', 		keep(1 3) nogen keepusing(gdppc2019_weo)
merge m:1 code using `pop2100',  		keep(1 3) nogen

forval yr = 2020/2100 {
    gen poor`yr' 	= pov`yr'/100 	 * pop`yr'
	gen socpoor`yr' = socpov`yr'/100 * pop`yr'
}																				// number of poor

drop pop2020-pop2100

compress
order country code region_wb incgroup2019 type pop2019 gdppc2019_weo pov* socpov* poor*
sort country type

global rate 	"0.03"															// 3% discount rate
global baseyear "2020"

forval yr = 2020/2100 {
	bys code (type): gen addpoor`yr' 	= poor`yr' 	  - poor`yr'[_n-1]
	bys code (type): gen addsocpoor`yr' = socpoor`yr' - socpoor`yr'[_n-1]
}																				// additional poor
drop if type=="Baseline"

forval yr = 2020/2100 {
	gen disaddpoor`yr'    = addpoor`yr' 	/(1 + $rate )^(`yr'-$baseyear)
	gen disaddsocpoor`yr' = addsocpoor`yr' 	/(1 + $rate )^(`yr'-$baseyear)
}																				// present value of discounted total poverty rate; discount rate 3%

// aggregate additional poor 
egen totaddpoor 	= rowtotal(addpoor*)
egen totaddsocpoor  = rowtotal(addsocpoor*)
egen disaddpoor 	= rowtotal(disaddpoor*)
egen disaddsocpoor  = rowtotal(disaddsocpoor*)

keep country code region_wb incgroup2019 pop2019 gdppc2019 tot* disaddpoor disaddsocpoor

label var pop2019   		"Population in 2019 (millions)"
label var gdppc2019 		"GDP per capita in 2019 (2017 PPP USD)"
label var totaddpoor 		"FPY, Total additional extreme poor (millions)"
label var totaddsocpoor 	"FPY, Total additional societal poor (millions)"
label var disaddpoor 		"FPY, Discounted additional extreme poor (millions)"
label var disaddsocpoor 	"FPY, Discounted additional societal poor (millions)" 

drop if pop2019 < 2.5 /* cutoff mentioned in paper */

export excel using "OutputData/FPY.xlsx", firstrow(varlabels) replace
save "OutputData/FPY.dta", replace

********************************************************************************

log close
