********************************************************************************
*** "Lives, Livelihoods, and Learning: A Global Perspective on the 			 ***
***  Well-being Impacts of the Covid-19 Pandemic"	     					 ***
***  By Benoit Decerf, Jed Friedman, Arthur Mendes, Steven Pennings, Nishant ***
***  Yonzan (bdecerf@worldbank.org, jfriedman@worldbank.org,                 ***
***  agalegomendes@worldbank.org, spennings@worldbank.org,                   ***
***  nyonzan@worldbank.org)												     ***
*** 							February 2023 								 ***
********************************************************************************

********************************************************************************
*** Purpose: 	Produce Figure 2 
********************************************************************************

* Results stored in  Results/Figure2.pdf
* First, run Alpha.do, CPY.do, FPY.do, YLL.do (inside DoFiles)

* Note: Change this directory ($path) to location of replication directory on 
* your computer (or run ReplicateAllTablesFiguresStata.do first)**
cls
cd "$path" 
log using "Logs/Figure2.log", replace

********************************************************************************

use "OutputData/FPY.dta", clear													// FPY
rename region_wb region
rename incgroup2019 incomegroup
rename code countrycode
rename disaddsocpoor FPY
drop gdppc2019_weo totaddpoor totaddsocpoor disaddpoor
tempfile FPY
save 	`FPY', replace

use "OutputData/CPY.dta", clear													// CPY
rename code countrycode
rename addsocpoor2020 CPY2020
rename addsocpoor2021 CPY2021
keep countrycode CPY2020 CPY2021
tempfile CPY
save 	`CPY', replace

use "OutputData/YLL.dta", clear													// YLL
rename year_life_lost YLL
tempfile YLL
save 	`YLL', replace

import delimited InputData/WDIEXCEL_extracted0923.csv, varnames(1) clear
local i=1960
forvalues x = 5(1)67 {
	rename v`x' y`i'
	local i = `i' + 1
}
keep if indicatorcode == "NY.GNP.PCAP.CD"
reshape long y, i(countryname) j(year)
rename y gnipc2020
label variable gnipc2020 "2020 GNI per capita, Atlas method (current US$)"
keep if year==2020
keep countrycode gnipc2020
tempfile gnipc2020
save 	`gnipc2020', replace

use `FPY', clear																// merge (countries used are in FPY)
merge 1:1 countrycode using `CPY'
assert _m != 1
drop if _m == 2
drop _m
merge 1:1 countrycode using `YLL'
assert _m != 1
drop if _m == 2
drop _m
merge 1:1 countrycode using `gnipc2020'
assert _m != 1
drop if _m == 2
drop _m

gen regioncode = ""																
replace regioncode = "LAC" if region == "Latin America & Caribbean"
replace regioncode = "ECA" if region == "Europe & Central Asia"
replace regioncode = "EAP" if region == "East Asia & Pacific"
replace regioncode = "NAM" if region == "North America"
replace regioncode = "SSA" if region == "Sub-Saharan Africa"
replace regioncode = "MENA" if region == "Middle East & North Africa"
replace regioncode = "SAS" if region == "South Asia"

gen incomegroupcode = ""														
replace incomegroupcode = "LI" if incomegroup == "Low income"
replace incomegroupcode = "LMI" if incomegroup == "Lower middle income"
replace incomegroupcode = "UMI" if incomegroup == "Upper middle income"
replace incomegroupcode = "HI" if incomegroup == "High income"

																				
gen YLL_per_100 = YLL/(pop2019*10000)											// variables per 100 people
gen FPY_per_100 = FPY*1000000/(pop2019*1000000/100)
gen CPY_per_100 = (CPY2020+CPY2021)*1000000/(pop2019*1000000/100)

gen ln_gnipc2020 = ln(gnipc2020)
sort gnipc2020

gen ratio1 = CPY_per_100/YLL_per_100
codebook ratio1 
codebook ratio1 
replace ratio1 = 15 if ratio1 > 15
replace ratio1 = 15 if YLL_per_100 < 0 & CPY_per_100 > 0
replace ratio1 = 0 if YLL_per_100 > 0 & CPY_per_100 < 0
replace ratio1 = . if YLL_per_100 < 0 & CPY_per_100 < 0
codebook ratio1 
gen totalPY = CPY_per_100 + FPY_per_100

gen ratio2 = totalPY/YLL_per_100
replace ratio2 = 15 if ratio2 > 15
replace ratio2 = 15 if YLL_per_100 < 0 & totalPY > 0
replace ratio2 = 0 if YLL_per_100 > 0 & totalPY < 0
replace ratio2 = . if YLL_per_100 < 0 & totalPY < 0
codebook ratio1 ratio2

// Regression for ratio1
regress ratio1 ln_gnipc2020

// Store the rounded coefficient for ln_gnipc2020 in a local macro
local slope_ratio1 : di round(_b[ln_gnipc2020], 0.01)
di "Rounded slope for ratio1: " string(`slope_ratio1', "%9.2f")

// Regression for ratio1
regress ratio2 ln_gnipc2020

// Store the rounded coefficient for ln_gnipc2020 in a local macro
local slope_ratio2 : di round(_b[ln_gnipc2020], 0.01)
di "Rounded slope for ratio2: " string(`slope_ratio2', "%9.2f")

//	Regressions for log2 scale
gen log2_gnipc2020 = log(gnipc2020)/log(2)
regress ratio1 log2_gnipc2020
predict predicted_ratio1, xb
local slope_ratio1 : di round(_b[log2_gnipc2020], 0.01)
di "Rounded slope for ratio1: " string(`slope_ratio1', "%9.2f")
regress ratio2 log2_gnipc2020
predict predicted_ratio2, xb
local slope_ratio2 : di round(_b[log2_gnipc2020], 0.01)
di "Rounded slope for ratio2: " string(`slope_ratio2', "%9.2f")

tw ///
scatter ratio1 gnipc2020, sort mlabcolor(navy%70) msymbol(circle) mcolor(navy%0) mlcolor(navy%70) lcolor(navy%70) msize(5pt) mlabsize(5pt) || ///
scatter ratio2 gnipc2020,  sort mlabcolor(maroon%70) msymbol(plus) mcolor(maroon%0) mlcolor(maroon%70) lcolor(maroon%0) msize(5pt) mlabsize(5pt)  ||		///
(line predicted_ratio1 gnipc2020, lcolor(navy%70) lwidth(0.4) lpattern(dash))  							///
(line predicted_ratio2 gnipc2020, lcolor(maroon%70) lwidth(0.4) lpattern(dash)),  		///
xtitle("GNI PC, Atlas Method (2020 US$, log{subscript:2} scale)", color(grey%70)) 					///
ytitle("Ratio of years in poverty to years of life lost", color(grey%80)) 		///
legend(order(1 2) row(1) label(1 Contemporaneous poverty) label(2 Contemporaneous and future poverty) size(10pt) color(grey%70)nobox region(style(none)) height(1)) ///
bgcolor(white) graphregion(color(white)) 										///
ylabel(0(5)15 , labcolor(grey%80) grid ) 										/// 
yscale(range(0 15) titlegap(2)) 												///
xsc(log) xlabel(250 500 1000 2000 4000 8000 16000 32000 64000, labcolor(grey%80) grid) 					///
xscale(range(250 64000) titlegap(1)) 											///
yline(1, lcolor(navy%70)) ytick(1)									
graph export "Results/Figure2.pdf", as(pdf) replace

********************************************************************************

log close
